@@ -5,7 +5,7 @@ test_that("get.data handles matrix without name correctly", {
   result <- get.data(data, endogenous = 1, addIntercept = FALSE)
   expect_equal(colnames(result$data), c("Y1","X1","X2","X3","X4","X5"))
   expect_equal(result$numExo, ncol(data) - 1)
-  expect_equal(result$obsCount, 4)
+  expect_equal(nrow(result$data), 4)
 
   result <- get.data(data, endogenous = 2, addIntercept = FALSE)
   expect_equal(colnames(result$data), c("Y1", "Y2", "X1","X2","X3","X4"))
@@ -54,14 +54,14 @@ test_that("get.data handles matrix without name correctly", {
   expect_equal(c(result$data[,3]), c(rep(1:4)))
   expect_equal(c(result$data[,4]), rep(1,4))
   expect_equal(c(result$data[,5]), c(9,10,11,12))
-  expect_equal(result$newObsCount,3)
+  expect_equal(nrow(result$newX),3)
   result <- ldt:::get.data.append.newX(result)
   expect_equal(c(result$data[,1]), c(1,2,3,4,NA,NA,NA))
   expect_equal(c(result$data[,2]), c(5,6,7,8,NA,NA,NA))
   expect_equal(c(result$data[,3]), c(rep(1:4), NA, NA, NA))
   expect_equal(c(result$data[,4]), rep(1,7))
   expect_equal(c(result$data[,5]), c(9,10,11,12,51,52,53))
-  expect_equal(result$newObsCount,3)
+  expect_equal(nrow(result$newX),3)
 
   newX <- matrix(51:62, ncol = 3)
   result <- get.data(data, endogenous = 3, newData = newX, addIntercept = TRUE, weights = c(1:4))
@@ -70,7 +70,7 @@ test_that("get.data handles matrix without name correctly", {
   result <- ldt:::get.data.append.newX(result)
   expect_equal(c(result$data[,1]), c(1,2,3,4,NA,NA,NA,NA))
   expect_equal(c(result$data[,8]), c(21,22,23,24,59,60,61,62))
-  expect_equal(result$newObsCount,4)
+  expect_equal(nrow(result$newX),4)
 
 })
 
@@ -82,7 +82,7 @@ test_that("get.data handles matrix with name correctly", {
   result <- get.data(data, endogenous = c("V6", "V1"), addIntercept = FALSE)
   expect_equal(colnames(result$data), c("V6","V1","V2","V3","V4","V5"))
   expect_equal(result$numExo, ncol(data) - 2)
-  expect_equal(result$obsCount, 4)
+  expect_equal(nrow(result$data), 4)
   expect_equal(result$data[,"V6"], data[,"V6"])
   expect_equal(result$data[,"V1"], data[,"V1"])
   expect_equal(result$data[,"V3"], data[,"V3"])
@@ -124,7 +124,7 @@ test_that("get.data handles equations correctly", {
   result <- get.data(data, equations = equations, addIntercept = FALSE)
   expect_equal(colnames(result$data), c("Y1","Y2","X2","X1","X4","X3"))
   expect_equal(result$numExo, ncol(data) - 2)
-  expect_equal(result$obsCount, 4)
+  expect_equal(nrow(result$data), 4)
   expect_equal(result$data[,"Y1"], data[,"Y1"])
   expect_equal(result$data[,"Y2"], data[,"Y2"])
   expect_equal(result$data[,"X3"], data[,"X3"])
@@ -133,7 +133,7 @@ test_that("get.data handles equations correctly", {
   result <- get.data(data, equations = equations, addIntercept = TRUE)
   expect_equal(colnames(result$data), c("Y1","Y2", "(Intercept)", "X2","X1","X4","X3"))
   expect_equal(result$numExo, ncol(data) - 1)
-  expect_equal(result$obsCount, 4)
+  expect_equal(nrow(result$data), 4)
   expect_equal(result$data[,"Y1"], data[,"Y1"])
   expect_equal(result$data[,"Y2"], data[,"Y2"])
   expect_equal(result$data[,"X3"], data[,"X3"])
